my eye

Use "guide" instead of "help" for the actual resource

Committed c8a5fb

--- a/canopy/static/enliven.js
+++ b/canopy/static/enliven.js

       }
     } else {
       switch (ev.key) {
-        case '?': goHelp(); break                    // ?   show help
+        case '?': goGuide(); break                   // ?   show the site guide
         case 'q': focusQuery(ev); break              // q   focus query input
         case 'f': showKeyboardFollowLinks(); break   // f   show "follow links"
         case 'm': goHome(); break                    // m   go home
 
 const em = parseFloat(getComputedStyle(document.documentElement).fontSize)
 
-const goHelp = () => { go('/help') }
+const showGuide = () => { go('/guide') }
 const focusQuery = ev => {
   document.querySelector('input[name=q]').focus()
   ev.preventDefault()
       partialContainer.innerHTML = ''
       return
     }
-    if (input == 'help') goHelp()                    // help
+    if (input == 'help') goGuide()                   // help
     else if (input.startsWith('query for')) {        // query for
       const query = input.slice(10)
       document.querySelector('input[name=q]').value = query

rename from canopy/templates/help.html
rename to canopy/templates/guide.html

 $def with ()
-$var title: Help
+$var title: Guide
 
 <style>
 dt {
 
 <dl>
 <dt>?
-<dd>show this help page
+<dd>show this page
 <dt>A-r
 <dd>toggle room mode
 <dt>A-s

--- a/canopy/templates/template.html
+++ b/canopy/templates/template.html

     <svg id=listen title=dictation width=14px height=14px viewBox="-0.5 0 25 25"
       fill=none xmlns=http://www.w3.org/2000/svg></svg>
     <input name=q type=text><br>
-    <small class=partial></small> <a href=/help>Help</a>
+    <small class=partial></small> <a href=/guide>Guide</a>
     </form>
 </div>
 </header>
--- a/canopy/__init__.py
+++ b/canopy/__init__.py

         return app.view.index()
 
 
-@app.control("help")
-class Help:
-    """Your help page."""
+@app.control("guide")
+class Guide:
+    """A guide to the canopy."""
 
     def get(self):
-        """Render your help page."""
-        return app.view.help()
+        """Render your site's guide."""
+        return app.view.guide()
